@@ -2,10 +2,9 @@
 #' @importFrom ggplot2 ggproto Stat StatBoxplot
 #' @format NULL
 #' @usage NULL
-#' @importFrom ggplot2 ggproto Stat
 #' @export
-StatBoxJitter <- ggproto("StatBoxJitter", Stat,
-   required_aes = c("x", "y"),
+StatBoxJitter <- ggproto("StatBoxJitter", StatBoxplot,
+   required_aes = c("y"),
    non_missing_aes = "weight",
    
    compute_group = function(data, scales, width = NULL, na.rm = FALSE, coef = 1.5) {
@@ -13,4 +12,4 @@ StatBoxJitter <- ggproto("StatBoxJitter", Stat,
      df$jitter_y <- list(data$y)
      df
    }
-)
\ No newline at end of file
+)
